# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic
Versioning](http://semver.org/spec/v2.0.0.html).

## [5.21.2] - 2020-08-31

### Fixed
- Fixed a bug where postgres errors could cause the backend to panic.

## [5.21.1] - 2020-08-05
*No changelog for this release.*

## [5.21.0] - 2020-06-10

### Added
- Added support to retrieve the serialized json license file for handler executions.
- Added entity class limits and entity class counts to license metadata.
- Added entity class counts as Tessen metrics.
- Added new OpenSSL-linked builds for sensu-agent & sensu-backend.
- Added `--require-openssl` and `--require-fips` flags to sensu-agent &
sensu-backend (OpenSSL-linked binaries only).

### Changed
- Updated the `sensuctl license info` tabular title to reflect entity class counts/limits in
addition to the total entity count/limit.

## [5.20.2] - 2020-05-26

### Changed
- Temporarily disable process discovery in the agent

## [5.20.1] - 2020-05-15

### Fixed
- Fixed a bug where the event & keepalive gauges could not be retrieved when
PostgreSQL was used for event storage.
- The libc implementation is now properly referenced in the federated dashboard.
- No longer capitalize the process names in the Web UI.
- The entity float type is no longer displayed in the Web UI.
- The display of % for CPU and memory usage has been fixed in the Web UI.

## [5.20.0] - 2020-05-12

### Added
- Added metricsd to collect metrics for the Web UI.
- Added PostgreSQL metrics suite to let metricsd collect metrics about events
stored in PostgreSQL.
- The current entity count and license limit have been added to the license
metadata.
- Adds `--discover-processes` flag and populates `processes` field in
`entity.system` if enabled.
- Set `Edition` version attribute to `enterprise`.
- Added `EntityClassLimits` to the license struct to map entity limits by the entity class.
- Added `--entity-class-limits` to the sensu-license command to generate licenses with specific
entity class limits.
- Enforce soft entity class limits (warning banners).
- Enforce hard entity class limits (restrict new entities)
- [Web] Added ability to configure application defaults.
- [Web] Added federated HUD.
- [Web] Added process and additional system information to entity details view.

### Fixed
- Database connections are no longer leaked after queries to the cluster health
API.

## [5.19.3] - 2020-04-30

### Fixed
- The backend no longer leaks goroutines on internal restart.

## [5.19.2] - 2020-04-27

### Added
- Added sql database connection pool options to store/v1.PostgresConfig.
- Added Ubuntu 19.10 (Eoan Ermine) and 20.04 (Focal Fossa) to the list of
packagecloud repositories we upload deb packages to.

## [5.19.1] - 2020-04-13

### Fixed
- Fixed a bug where the postgres store would be enabled too late on startup,
leading to keepalive bugs and possibly other bugs.

## [5.19.0] - 2020-03-26

### Added
- Added `PostgresHealth` information to the `/health` endpoint.
- Added `matches` as an operator for api filtering selectors.
- Added agent & sensuctl builds for `linux` architectures: `mips`, `mipsle`,
`mips64` and `mips64le` (both `softfloat` and `hardfloat`).
- [Web] Added ability to save, recall, and delete searches.
- Added `sensuctl prune` command.
- Added Tessen metrics for auth providers, secrets & secrets providers.

## Fixed
- Fixed a bug where event.Check.State was not set for events passing through
the pipeline, or for events written to the event log.

## [5.18.1] - 2020-03-10

## Fixed
- Fixed a bug where OIDC login can result in a nil pointer panic.
- Fixed a bug that was causing SQL migrations to fail on PostgresQL 12.

## [5.18.0] - 2020-02-20

### Changed
- Updated Go version from 1.13.5 to 1.13.7.

### Fixed
- Field and label selectors now accept single and double quotes to identify
strings.

## [5.17.2] - 2020-02-19

### Fixed
- Fixed a panic on backend restart.

## [5.17.1] - 2020-01-31

### Changed
- Vendor `sensu/sensu-go` @ 9c0a793f79e4a4f874cf0f1868e98e295d931822

### Fixed
- [Web] Re-enables polling on the silences view

## [5.17.0] - 2020-01-28

### Added
- Added the secret resource.
- Added the secrets provider resource `secrets/v1.Provider`.
- Added the HTTP API for secrets provider management `/api/enterprise/secrets/v1/providers`.
- Implemented the built-in `Env` secrets provider.
- Added `sensuctl secret` subcommands for `list`, `info`, and `delete`.
- Added the vault secret provider
- Added `PERMISSION.pdf` to the Chocolatey packages.
- Added the ability to override the cluster admin username & password for
`sensu-backend init` in Docker.
- UPN binding support has been re-introduced via the `default_upn_domain`
configuration attribute.

### Fixed
- Upgraded the size of the events auto-incremented id in the postgres store.
This allows storing many more events, and also fixes an issue where the
sequence can be exhausted.
- Fixed a bug where the event check state was not present when using the
postgresql event store.
- Agent TLS authentication does not require a license.
- Fixed a bug where OIDC auth tokens were unable to be refreshed in the web app.

## [5.16.1] - 2019-12-18

### Fixed
- Fixed a performance regression that was introduced in 5.15.0, which would
cause the API to timeout past 20k agent sessions.

## [5.16.0] - 2019-12-11

### Added
- [Web] Added ability to authenticate with OIDC.
- Added sensu-backend init.
- Label selectors now match the event's check & entity labels.
- Added `solaris/amd64` to the list of targets we build sensu-agent tarball
releases for.

### Changed
- The entity limit warning message is now displayed less aggressively and the
  warning threshold is proportional to the entity limit.

### Fixed
- Queries with no results return an empty array.
- `agent.yml.example` file shipped with Sensu Agent for Windows packages now
uses DOS-style line endings.
- Fixed a bug where replicators with multiple comma-separated URLs would not connect.

## [5.15.0] - 2019-11-18

### Added
- Added support for federation replicators.
- Added support for the federation cluster registration api.
- MSI & NuGet builds for sensu-cli (sensuctl).
- MSI & NuGet installations now add the bin dir to system PATH on Windows.
- Added a hard entity limiter middleware to restrict PUT/POST for entities
and events if the entity limit has been reached.
- Added a hard agent limiter middleware to restrict new agent websocket
connections if the entity limit has been reached.
- Added API endpoint for /license (DELETE).
- [Web] Added ability to view resources across clusters in the federation.

### Removed
- Removed support for UPN binding without a binding account or anonymous
binding.
- Removed limitd in favor of a simplified EntityLimiter (which uses the
resource cache).

### Changed
- Updated the entity limit middleware headers with context about hard entity limits,
and added headers to warn users if they are approaching the limit (at 75%).
- [Web] Pull new entity limit warning from response headers.
- Decreased the free entity limit from 1000 to 100.

## [5.14.2] - 2019-11-04

### Added
- Added `el/8` to the list of package repositories we upload to.

## [5.14.1] - 2019-10-16

### Fixed
- Fixed a bug where sensuctl would erroneously warn of entity limits for
unlimited licenses.
- Fixed a bug where the `oidc` authentication providers would not be properly
loaded on start-up.

## [5.14.0] - 2019-10-08

### Added
- Added support for mutual TLS authentication between agents and backends.
- Added support for CRL URLs for mTLS authentication.

### Fixed
- sensuctl can now create federation resources.
- sensuctl on Windows can now create postgres resources.
- Fixed a bug where event metrics would be ignored when using the postgres store.

## Changed
- Updated Go version from 1.12.3 to 1.13.1.

## [5.13.2] - 2019-09-19

### Fixed
- Make sure metrics handlers fire when using the PostgreSQL store.

## [5.13.1] - 2019-09-10

### Fixed
- Fixed the `oidc` authentication provider resource.

## [5.13.0] - 2019-09-09

### Added
- Added the `Sensu-Entity-Warning` header for all API requests (via a middleware).
- Added an entity limit warning banner on all tabular `sensuctl list` commands if the
free/license entity limit has been exceeded.
- Added the federation API


### Fixed
- Fixed a bug where silences would not expire on event resolution.

## [5.12.0] - 2019-08-22

### Added
- Added `freebsd/386` and `freebsd/amd64` binary builds for sensu-agent & sensuctl.
- Injects `auth` and `license` as possible `sensuctl dump` options.
- [Web] Added support for virtual fields in the form generator
- Added OIDC authentication provider.
- Added new `sensuctl login` command, with an `oidc` subcommand.

### Changed
- `.tar.gz` and `.zip` releases no longer have `-enterprise` in the name.
- The project now uses Go modules instead of dep for dependency management.
- Updated goreleaser to v0.114.1 & now using import paths for ldflags as required by go modules.
- [Web] Namespace selector now uses user-namespaces endpoint (and the oss endpoint as a backup)

## [5.11.1] - 2019-07-18

### Changed
- Vendor `sensu/sensu-go` @ 79890a9d509ff219af400af2816adcdd4a8c2592

### Fixed
- Fixed access token renewal when UPN format binding was enabled.

## [5.11.0] - 2019-07-10

### Added
- Added `debian/buster` to the list of package repositories we upload to.
- Added support for LDAP UPN authentication (Active Directory only).
- Added support for including nested groups in LDAP group searches (Active Directory only).
- [Web] Allow users to manage (view, create, edit, delete) Event Filter resources via the dashboard.
- [Web] Allow users to manage (view, create, edit, delete) Mutator resources via the dashboard.
- Added /user-namespaces route to deliver a curated list of namespaces the user has access to.

### Fixed
- [Web] Creating a Check or Handler within the same namespace with a duplicate name now throws an error instead updating the existing resource.

### Changed
- Updated goreleaser to v0.112.1 & added support for zip archives.

### Removed
- Removed `el/5` from the list of package repositories we upload to.

## [5.10.2] - 2019-06-27

### Fixed
- Fixed an issue where license expiration could lead to a backend crash

## [5.10.1] - 2019-06-25

### Changed
- Vendor `sensu/sensu-go` @ b2f432747653965c48ea806ee4852cd4916be22f

## [5.10.0] - 2019-06-18

### Added
- Added a `SetNamespace(string)` function to enterprise resources to satisfy the `Resource` interface.
- [Web] Added filtering input fields to each resource (Checks, Entities, Events, Handlers, and Silences).
- Added the postgresql event store.
- [Web] Publish tessen metrics for homepage tile click events.
- [Web] Form generator allows for branching logic and requirements. Uses dependencies/dependants for displaying fields.
- [Web] Form generator no longer sends empty strings/arrays/etc

### Changed
- [Web] Un-licensed users can delete entities
- [Web] Updating the embedded assets no longer requires `node` & `yarn`.

### Fixed
- [Web] Links on the "Incidents Tile" and "Entities Tile" on the dashboard homepage now correctly filter events when navigating to their respective pages.
- [Web] Ensure that editing a resource triggers a refetch of the resource so that the edit dialoque is up-to-date.
- [Web] Normalize empty arrays on form submit, so that creating resources does not cause users to submit empty strings within array fields.
- [Web] Remove recursive defaults when updating a resource to allow users to properly update array field values.
- [Web] Use new filter syntax on homepage; avoids having to filter entire set of events.
- [Web] Set upper limit of events & entities fetched on the homepage from 1k to 100k.
- Allow RBAC rules for license resource be applied
- [Web] Properly reflect current count of keepalives on landing page.

## [5.9.0] - 2019-05-29

### Added
- GraphQL fields that previously accepted JS statements for filtering will now
accept field and label selectors.
- Added a field to the license struct and license generation command that allows
licensed users to opt out of Tessen.
- [Web] Added the ability to create a Handler resource from the dashboard
- Added raw event logging functionality
- [Web] Added the ability to edit or delete a Handler resource from the dashboard.
- Added Ubuntu 19.04 (Disco Dingo) to the list of packagecloud repositories we
upload deb packages to.

### Changed
- Vendor `sensu/sensu-go` @ 5ffdd07
- Vendor `sensu/web` @ SHA a25de7f
- Updated embedded web app assets 612288b...a25de7f

## [5.8.0] - 2019-05-22

### Added
- Added entity limits to the license struct and license generation command.
- Added entity limit banner for limited licenses
- Added a README for the Form Generator

### Changed
- Vendor sensu/web @ SHA e8642b2
- Updated embedded web app assets 87a4066...612288b

## [5.7.0] - 2019-05-09

### Added
- Added LimitD, a backend daemon that collects and maintains a history of the total entity count.
- Added EntityLimiter, an API middleware that appends `Sensu-Entity-Limit` and `Sensu-Entity-Count`
headers to all `/api/core` and `/api/enterprise` responses.
- [Web] Added banner to display entity limit & count, if cluster is over limit.
- Added tooling to produce Windows packages for sensu-agent.

### Changed
Updated the sensu-agent entrypoint to support the changes in sensu-go
related to Windows services.

### Fixed
- The API returns an error message if label and field selectors are used without
a license, instead of ignoring the query parameters.

## [5.6.0] - 2019-04-30

### Fixed
- Fixed incorrect checbox state in header of emtpy list views. (Visual bug)
- Avoid "Failed to fetch" errors on landing page.

### Added
- Added label selector filtering as a licensed feature
- Added field selector filtering as a licensed feature
- Added `--field-selector` and `--label-selector` support to `sensuctl`
- Ability to edit a check
- Ability to create a check
- Ability to delete checks and entities
- Add support for LDAP/AD anonymous binding
- Add support for mutual TLS for the LDAP and AD auth providers

## [5.5.1] - 2019-04-17

### Added
- [Web] form generator for building form
- [Web] initial check form schema

### Changed
- Updated Go version from 1.11.5 to 1.12.3.
- sensu-go updated, contains bugfixes

## [5.5.0] - 2019-04-03

### Changed
- sensu-go updated, contains tessen

## [5.4.0] - 2019-03-27

### Added

- Set up enterprise web-ui app
- Serve enterprise specific dashboard assets.
- [Web] added new homepage

## [5.3.0] - 2019-03-07

### Added
- Added the Active Directory authentication provider.

### Fixed
- DNS resolution in alpine linux containers is now done with the built-in Go
resolver. Previously, the binaries would attempt to use the glibc resolver,
which is not present in MUSL.

## [5.2.1] - 2019-02-11

### Fixed
- Revendored sensu-go to include a fix that addressed a regression in
proxy check execution.

## [5.2.0] - 2019-02-06

### Added
- Added a watcher, as a licensed feature, to manage the list of enabled
providers in the Authenticator.
- Add Debian 8 (jessie) & Debian 9 (stretch) to the platforms we build packages
for.
- Added the LDAP authentication provider.
- Added the `authentication/v2` API group.
- Added a generic store.
- Added a generic CLI client.
- Added a generic API controller.

### Changed
- Use Goreleaser for tarball & binary builds.
- Moved the license API to `licensing/v2` API group.

### Fixed
- Fixed Ubuntu package naming & release version.
- The license is now stored with its signature for validation.

## 5.1.1

### Added
- Added the sensu-license command to generate license files.
- Added a test job in CircleCI.
- Added sensuctl auth command.
- Added support for authentication providers in `sensuctl create`.

### Changed
- Regenerated the private/public keypair for license files.
- Refactoring of the licensing package.
- Updated Go version from 1.10 to 1.11.5.
- Updated sensu-go to d8a8a46e85c9bf24d46858126a21866d40b283ba.

## 5.1.0

### Added
- Add Ubuntu 14.04 (trusty) to the platforms we build packages for.

### Changed
- Updated sensu-go to 3731bcda2c40b39f162675dad0fa269b761e9da5.

### Fixed
- Prevent a panic when using an external etcd cluster.
- Fixed run & log paths in sysvinit scripts for agent & backend.

## 5.0.1

### Changed
- Updated sensu-go to 0150bbc.

## 5.0.0

### Added
- First release of sensu-enterprise-go. Includes sensu-go vendored at a specific
SHA. In the future, sensu-go will be vendored at a tag.
